Documentation
¶
Index ¶
- type Client
- func (c *Client) ConnectAp(ssid string, p string, ap2device map[string]string, ssid2ap map[string]string) error
- func (c *Client) Connected(devices []string) bool
- func (c *Client) ConnectedWifi(wifiDevices []string) bool
- func (c *Client) DisconnectWifi(wifiDevices []string) int
- func (c *Client) GetAccessPoints(devices []string, ap2device map[string]string) []string
- func (c *Client) GetDevices() []string
- func (c *Client) GetWifiDevices(devices []string) []string
- func (c *Client) SetIfaceManaged(iface string, state bool, devices []string) string
- func (c *Client) Ssids() ([]SSID, map[string]string, map[string]string)
- func (c *Client) WifisManaged(wifiDevices []string) (map[string]string, error)
- type DbusClient
- type Objecter
- type SSID
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client type to support unit test mock and runtime execution
func (*Client) ConnectAp ¶
func (c *Client) ConnectAp(ssid string, p string, ap2device map[string]string, ssid2ap map[string]string) error
ConnectAp attempts to Connect to an external AP
func (*Client) ConnectedWifi ¶
ConnectedWifi checks if any passed wifi devices are connected
func (*Client) DisconnectWifi ¶
DisconnectWifi disconnects every interface passed. return shows number of disconnect calls made
func (*Client) GetAccessPoints ¶
GetAccessPoints returns NetMan known external APs
func (*Client) GetDevices ¶
GetDevices returns NetMan (NetworkManager) devices
func (*Client) GetWifiDevices ¶
GetWifiDevices returns wifi NetMan devices
func (*Client) SetIfaceManaged ¶
SetIfaceManaged sets passed device to be managed/unmanaged by network manager, return iface set, if any
type DbusClient ¶
type DbusClient struct {
BusObj dbus.BusObject
Connection *dbus.Conn
// contains filtered or unexported fields
}
DbusClient properties for testing & runtime
func (*DbusClient) Object ¶
func (d *DbusClient) Object(dest string, path dbus.ObjectPath) dbus.BusObject
Object is the mock implementation of the godbus Object function
Click to show internal directories.
Click to hide internal directories.